# Gitea Action Runner with Tailscale Integration

This project sets up a Gitea Action Runner instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your Gitea Action Runner instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
ts-gitea-act-runner/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/  # Persistent Tailscale state
│   └── config/         # Tailscale configuration files
└── gitea-act-runner/
    └── config/         # gitea-act-runner configuration files
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/ts-gitea-act-runner
   cd ts-gitea-act-runner
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations
        - CAUTION: Changing `"${TS_CERT_DOMAIN}:443": false` to `true` will expose the service to the internet

4. Configure Gitea Action Runner
    - See {{service_docs}} for configuration options

5. Start the Services
    ```bash
    docker compose up -d
    ```

6. Wait for Certificate to propagate [~2m] 

7. Login 
    - After starting the services your service should be available via tailnet at https://gitea-act-runner.{{YOUR_TAILNET_DOMAIN}}.ts.net ie https://gitea-act-runner.tail12345.ts.net/

## Services

### gitea-act-runner-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: gitea-act-runner-ts
- Hostname: gitea-act-runner
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### gitea-act-runner

- Depends on gitea-act-runner-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://gitea-act-runner.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://gitea-act-runner.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs gitea-act-runner-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 3000:3000
    ```
- Stopping the Services
    ```bash
    docker compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs gitea-act-runner-ts
    docker logs gitea-act-runner
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting

## Notes
- The Gitea Action Runner service uses the Tailscale service's network stack via `network_mode: service:gitea-act-runner-ts`
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
    - Tailscale documentation: https://tailscale.com/kb/
    - Gitea Action Runner documentation: https://docs.gitea.com/usage/actions/quickstart
    - Gitea Action Runner repository: https://gitea.com/gitea/act_runner